@@ -614,7 +614,7 @@ class Commit(object):
 
         s = {
             "creator": creator,
-            "fee": "%.3s STEEM" % float(delegation_fee_hive or required_fee_hive),
+            "fee": "%s STEEM" % float(required_fee_hive),
             # "delegation": "%s VESTS" % required_fee_vests,
             "json_metadata": json_meta or {},
             "memo_key": memo,
